==> codepipeline-api-0.10.0-sources.jar: software/amazon/awscdk/services/codepipeline/api/$Module.java <==
package software.amazon.awscdk.services.codepipeline.api;

import static java.util.Arrays.asList;

import java.util.List;
import software.amazon.jsii.JsiiModule;

public final class $Module extends JsiiModule {
    public $Module() {
        super("@aws-cdk/aws-codepipeline-api", "0.10.0", $Module.class, "aws-codepipeline-api@0.10.0.jsii.tgz");
    }

    @Override
    public List<Class<? extends JsiiModule>> getDependencies() {
        return asList(software.amazon.awscdk.services.events.$Module.class, software.amazon.awscdk.services.iam.$Module.class, software.amazon.awscdk.$Module.class);
    }

    @Override
    protected Class<?> resolveClass(final String fqn) throws ClassNotFoundException {
        switch (fqn) {
            case "@aws-cdk/aws-codepipeline-api.Action": return software.amazon.awscdk.services.codepipeline.api.Action.class;
            case "@aws-cdk/aws-codepipeline-api.ActionArtifactBounds": return software.amazon.awscdk.services.codepipeline.api.ActionArtifactBounds.class;
            case "@aws-cdk/aws-codepipeline-api.ActionCategory": return software.amazon.awscdk.services.codepipeline.api.ActionCategory.class;
            case "@aws-cdk/aws-codepipeline-api.ActionProps": return software.amazon.awscdk.services.codepipeline.api.ActionProps.class;
            case "@aws-cdk/aws-codepipeline-api.Artifact": return software.amazon.awscdk.services.codepipeline.api.Artifact.class;
            case "@aws-cdk/aws-codepipeline-api.ArtifactPath": return software.amazon.awscdk.services.codepipeline.api.ArtifactPath.class;
            case "@aws-cdk/aws-codepipeline-api.BuildAction": return software.amazon.awscdk.services.codepipeline.api.BuildAction.class;
            case "@aws-cdk/aws-codepipeline-api.BuildActionProps": return software.amazon.awscdk.services.codepipeline.api.BuildActionProps.class;
            case "@aws-cdk/aws-codepipeline-api.CommonActionProps": return software.amazon.awscdk.services.codepipeline.api.CommonActionProps.class;
            case "@aws-cdk/aws-codepipeline-api.DeployAction": return software.amazon.awscdk.services.codepipeline.api.DeployAction.class;
            case "@aws-cdk/aws-codepipeline-api.DeployActionProps": return software.amazon.awscdk.services.codepipeline.api.DeployActionProps.class;
            case "@aws-cdk/aws-codepipeline-api.IStage": return software.amazon.awscdk.services.codepipeline.api.IStage.class;
            case "@aws-cdk/aws-codepipeline-api.SourceAction": return software.amazon.awscdk.services.codepipeline.api.SourceAction.class;
            case "@aws-cdk/aws-codepipeline-api.SourceActionProps": return software.amazon.awscdk.services.codepipeline.api.SourceActionProps.class;
            default: throw new ClassNotFoundException("Unknown JSII type: " + fqn);
        }
    }
}

==> codepipeline-api-0.11.0-sources.jar: software/amazon/awscdk/services/codepipeline/api/$Module.java <==
package software.amazon.awscdk.services.codepipeline.api;

import static java.util.Arrays.asList;

import java.util.List;
import software.amazon.jsii.JsiiModule;

public final class $Module extends JsiiModule {
    public $Module() {
        super("@aws-cdk/aws-codepipeline-api", "0.11.0", $Module.class, "aws-codepipeline-api@0.11.0.jsii.tgz");
    }

    @Override
    public List<Class<? extends JsiiModule>> getDependencies() {
        return asList(software.amazon.awscdk.services.events.$Module.class, software.amazon.awscdk.services.iam.$Module.class, software.amazon.awscdk.$Module.class);
    }

    @Override
    protected Class<?> resolveClass(final String fqn) throws ClassNotFoundException {
        switch (fqn) {
            case "@aws-cdk/aws-codepipeline-api.Action": return software.amazon.awscdk.services.codepipeline.api.Action.class;
            case "@aws-cdk/aws-codepipeline-api.ActionArtifactBounds": return software.amazon.awscdk.services.codepipeline.api.ActionArtifactBounds.class;
            case "@aws-cdk/aws-codepipeline-api.ActionCategory": return software.amazon.awscdk.services.codepipeline.api.ActionCategory.class;
            case "@aws-cdk/aws-codepipeline-api.ActionProps": return software.amazon.awscdk.services.codepipeline.api.ActionProps.class;
            case "@aws-cdk/aws-codepipeline-api.Artifact": return software.amazon.awscdk.services.codepipeline.api.Artifact.class;
            case "@aws-cdk/aws-codepipeline-api.ArtifactPath": return software.amazon.awscdk.services.codepipeline.api.ArtifactPath.class;
            case "@aws-cdk/aws-codepipeline-api.BuildAction": return software.amazon.awscdk.services.codepipeline.api.BuildAction.class;
            case "@aws-cdk/aws-codepipeline-api.BuildActionProps": return software.amazon.awscdk.services.codepipeline.api.BuildActionProps.class;
            case "@aws-cdk/aws-codepipeline-api.CommonActionConstructProps": return software.amazon.awscdk.services.codepipeline.api.CommonActionConstructProps.class;
            case "@aws-cdk/aws-codepipeline-api.CommonActionProps": return software.amazon.awscdk.services.codepipeline.api.CommonActionProps.class;
            case "@aws-cdk/aws-codepipeline-api.DeployAction": return software.amazon.awscdk.services.codepipeline.api.DeployAction.class;
            case "@aws-cdk/aws-codepipeline-api.DeployActionProps": return software.amazon.awscdk.services.codepipeline.api.DeployActionProps.class;
            case "@aws-cdk/aws-codepipeline-api.IStage": return software.amazon.awscdk.services.codepipeline.api.IStage.class;
            case "@aws-cdk/aws-codepipeline-api.SourceAction": return software.amazon.awscdk.services.codepipeline.api.SourceAction.class;
            case "@aws-cdk/aws-codepipeline-api.SourceActionProps": return software.amazon.awscdk.services.codepipeline.api.SourceActionProps.class;
            default: throw new ClassNotFoundException("Unknown JSII type: " + fqn);
        }
    }
}
